<div align='center'>
  <br />
  <p>
    <a href='https://github.com/YapleeProject/Yaplee'><img src='https://raw.githubusercontent.com/YapleeProject/Yaplee/master/images/logo.png' width='546' alt='Yaplee Logo' /></a>
  </p>
    <br />
  <p>
    <img src='https://img.shields.io/badge/License-MIT-blue' alt='' />  <img src='https://img.shields.io/badge/Testing-passing-green?logo=github' alt='' /> <img src='https://img.shields.io/badge/Python-> 3.6-red?logo=python' alt='' /> 

  </p>
</div>

## About
Yaplee is a Powerful, Fun and Open Souce MIT-Licenced project for front-end programming in Python.
Yaplee framework is very simple and does not have complicated details.

## Quick installation
To quickly install the Yaplee project, just use the " ```pip install yaplee``` " command.

## Documents
You can see the full document of this project from the official website of Yaplee ( [docs.yaplee.ir](http://docs.yaplee.ir) ) or from ( [https://yaplee.readthedocs.io](https://yaplee.readthedocs.io) )